<!DOCTYPE html>
<html>
<head>
  <title>PyaaS - {% block title %}Main{% end %}</title>
  {% block head %}{% end %}
  {% block templates %}{% end %}
</head>
<body>
  {% block body %}<a href="/main">Authenticate</a>{% end %}
</body>
</html>
